@@ -7,6 +7,7 @@
 #' @inheritParams cohortDoc
 #' @inheritParams cohortIdSubsetDoc
 #' @inheritParams nameDoc
+#' @inheritParams keepOriginalCohortsDoc
 #' @param matchSex Whether to match in sex.
 #' @param matchYearOfBirth Whether to match in year of birth.
 #' @param ratio Number of allowed matches per individual in the target cohort.
@@ -34,6 +35,7 @@ matchCohorts <- function(cohort,
                          matchSex = TRUE,
                          matchYearOfBirth = TRUE,
                          ratio = 1,
+                         keepOriginalCohorts = FALSE,
                          name = tableName(cohort)) {
   cli::cli_inform("Starting matching")
 
@@ -64,6 +66,10 @@ matchCohorts <- function(cohort,
   tablePrefix <- omopgenerics::tmpPrefix()
   target <- omopgenerics::uniqueTableName(tablePrefix)
   control <- omopgenerics::uniqueTableName(tablePrefix)
+  if (keepOriginalCohorts) {
+    keep <- omopgenerics::uniqueTableName(tablePrefix)
+    cdm[[keep]] <- subsetCohorts(cohort, cohortId, name = keep)
+  }
 
   if (cohort |> settings() |> nrow() == 0) {
     cdm[[name]] <- cohort |>
@@ -166,12 +172,22 @@ matchCohorts <- function(cohort,
     )
 
   # Bind both cohorts
-  cli::cli_inform(c("Binding both cohorts"))
-  cdm <- omopgenerics::bind(cdm[[target]], cdm[[control]], name = name)
+  cli::cli_inform(c("Binding cohorts"))
+  cohorts <- list(cdm[[target]], cdm[[control]])
+  if (keepOriginalCohorts) cohorts <- c(list(cdm[[keep]]), cohorts)
+  cdm <- do.call(omopgenerics::bind, c(cohorts, "name" = name))
 
   # drop tmp tables
   omopgenerics::dropTable(cdm = cdm, name = dplyr::starts_with(tablePrefix))
 
+  useIndexes <- getOption("CohortConstructor.use_indexes")
+  if (!isFALSE(useIndexes)) {
+    addIndex(
+      cohort = cdm[[name]],
+      cols = c("subject_id", "cohort_start_date")
+    )
+  }
+
   # Return
   cli::cli_inform(c("v" = "Done"))
   return(cdm[[name]])
@@ -186,9 +202,9 @@ getNewCohort <- function(cohort, cohortId, control) {
     name = temp_name,
     table = dplyr::tibble("cohort_definition_id" = cohortId)
   )
-  controls <- cdm[[temp_name]] %>%
+  controls <- cdm[[temp_name]] |>
     dplyr::cross_join(
-      cdm[["person"]] %>%
+      cdm[["person"]] |>
         dplyr::select("subject_id" = "person_id") |>
         dplyr::inner_join(
           cdm[["observation_period"]] |>
@@ -204,7 +220,7 @@ getNewCohort <- function(cohort, cohortId, control) {
             dplyr::ungroup(),
           by = "subject_id"
         )
-    ) %>%
+    ) |>
     dplyr::compute(name = control, temporary = FALSE)
   cdm <- omopgenerics::dropTable(cdm, temp_name)
 
@@ -260,8 +276,8 @@ addMatchCols <- function(x, matchCols) {
     dplyr::compute(name = omopgenerics::tableName(x), temporary = FALSE)
 }
 excludeIndividualsWithNoMatch <- function(cohort, groups, matchCols) {
-  cohort %>%
-    dplyr::inner_join(groups, by = c("cohort_definition_id", matchCols)) %>%
+  cohort |>
+    dplyr::inner_join(groups, by = c("cohort_definition_id", matchCols)) |>
     dplyr::select(!dplyr::all_of(matchCols)) |>
     dplyr::compute(name = tableName(cohort), temporary = FALSE) |>
     omopgenerics::recordCohortAttrition("Exclude individuals that do not have any match")
@@ -294,20 +310,20 @@ excludeNoMatchedIndividuals <- function(cdm,
                    temporary = FALSE)
 
   # Exclude individuals that do not have any match
-  cdm[[target]] <- cdm[[target]] %>%
+  cdm[[target]] <- cdm[[target]] |>
     excludeIndividualsWithNoMatch(groups, matchCols)
-  cdm[[control]] <- cdm[[control]] %>%
+  cdm[[control]] <- cdm[[control]] |>
     excludeIndividualsWithNoMatch(groups, matchCols)
 
   return(cdm)
 }
 
 addRandPairId <- function(x) {
-  x %>%
-    dplyr::mutate("id" = stats::runif(n = dplyr::n())) %>%
-    dplyr::arrange(.data$id) %>%
-    dplyr::mutate("pair_id" = dplyr::row_number(), .by = "group_id") %>%
-    dplyr::select(-"id") %>%
+  x |>
+    dplyr::mutate("id" = stats::runif(n = dplyr::n())) |>
+    dplyr::arrange(.data$id) |>
+    dplyr::mutate("pair_id" = dplyr::row_number(), .by = "group_id") |>
+    dplyr::select(-"id") |>
     dplyr::compute(name = omopgenerics::tableName(x), temporary = FALSE)
 }
 addClusterId <- function(x, u) {
@@ -325,23 +341,23 @@ clusterId <- function(x) {
 }
 infiniteMatching <- function(cdm, target, control) {
   # Create pair id to perform a random match
-  cdm[[target]] <- cdm[[target]] %>% addRandPairId()
-  cdm[[control]] <- cdm[[control]] %>% addRandPairId()
+  cdm[[target]] <- cdm[[target]] |> addRandPairId()
+  cdm[[control]] <- cdm[[control]] |> addRandPairId()
 
-  cdm[[control]] <- cdm[[control]] %>%
+  cdm[[control]] <- cdm[[control]] |>
     dplyr::inner_join(
       # Calculate the maximum number of cases per group
-      cdm[[target]] %>%
-        dplyr::group_by(.data$group_id) %>%
+      cdm[[target]] |>
+        dplyr::group_by(.data$group_id) |>
         dplyr::summarise(
           "max_id" = max(.data$pair_id, na.rm = TRUE),
           .groups = "drop"
         ),
       by = c("group_id")
-    ) %>%
+    ) |>
     # Calculate the maximum ratio per group
-    dplyr::mutate("pair_id" = ((.data$pair_id - 1) %% .data$max_id) + 1) %>%
-    dplyr::select(-"max_id") %>%
+    dplyr::mutate("pair_id" = ((.data$pair_id - 1) %% .data$max_id) + 1) |>
+    dplyr::select(-"max_id") |>
     dplyr::compute(name = control, temporary = FALSE)
 
   clusterId <- clusterId(cdm[[target]])
@@ -349,13 +365,13 @@ infiniteMatching <- function(cdm, target, control) {
   cdm[[target]] <- cdm[[target]] |> addClusterId(clusterId)
 
   # assign cohort_start_date and cohort end date to controls
-  cdm[[control]] <- cdm[[control]] %>%
+  cdm[[control]] <- cdm[[control]] |>
     dplyr::inner_join(
       # Cohort start date and end date of cases
-      cdm[[target]] %>%
+      cdm[[target]] |>
         dplyr::select("cluster_id", "index_date" = "cohort_start_date"),
       by = c("cluster_id")
-    ) %>%
+    ) |>
     dplyr::compute(name = control, temporary = FALSE)
 
   return(cdm)
@@ -393,15 +409,15 @@ observationTarget <- function(cdm, target, control) {
 
 checkRatio <- function(x, ratio) {
   if (!is.infinite(ratio)) {
-    x <- x %>%
-      dplyr::mutate("id" = stats::runif(n = dplyr::n())) %>%
-      dplyr::group_by(.data$cluster_id) %>%
-      dplyr::arrange(.data$id) %>%
-      dplyr::filter(dplyr::row_number() <= .env$ratio) %>%
-      dplyr::ungroup() %>%
+    x <- x |>
+      dplyr::mutate("id" = stats::runif(n = dplyr::n())) |>
+      dplyr::group_by(.data$cluster_id) |>
+      dplyr::arrange(.data$id) |>
+      dplyr::filter(dplyr::row_number() <= .env$ratio) |>
+      dplyr::ungroup() |>
       dplyr::arrange() |>
       dplyr::select(-"id") |>
-      dplyr::compute(name = tableName(x), temporary = FALSE) %>%
+      dplyr::compute(name = tableName(x), temporary = FALSE) |>
       omopgenerics::recordCohortAttrition("Exclude individuals to fulfil the ratio")
   }
   return(x)
