@@ -42,10 +42,6 @@ trimDemographics <- function(cohort,
   ids <- settings(cohort)$cohort_definition_id
 
   # replace age Inf to avoid potential sql issues
-  for (j in seq_along(ageRange)) {
-    ageRange[[j]][is.infinite(ageRange[[j]])] <- as.integer(999)
-  }
-
   # temp tables
   tablePrefix <- omopgenerics::tmpPrefix()
   tmpName <- omopgenerics::uniqueTableName(tablePrefix)
@@ -64,9 +60,9 @@ trimDemographics <- function(cohort,
     omopgenerics::newCohortTable(.softValidation = TRUE)
 
   if (!is.null(ageRange) ||
-    !is.null(minPriorObservation) ||
-    !is.null(minFutureObservation) ||
-    !is.null(sex)) {
+      !is.null(minPriorObservation) ||
+      !is.null(minFutureObservation) ||
+      !is.null(sex)) {
     cli::cli_inform(c("Adding demographics information"))
     newCohort <- newCohort |>
       PatientProfiles::addDemographics(
@@ -91,6 +87,7 @@ trimDemographics <- function(cohort,
     minFutureObservation = minFutureObservation,
     requirementInteractions = TRUE
   )
+
   # insert settings
   cdm <- omopgenerics::insertTable(
     cdm = cdm,
@@ -131,7 +128,7 @@ trimDemographics <- function(cohort,
     cli::cli_inform(c("Trim sex"))
     newCohort <- newCohort |>
       dplyr::filter(.data$sex == .data$sex_req |
-        .data$sex_req == "Both") |>
+                      .data$sex_req == "Both") |>
       dplyr::compute(name = tmpNewCohort, temporary = FALSE)
     # attrition
     uniqueSex <- unique(newSet$sex)
@@ -152,8 +149,13 @@ trimDemographics <- function(cohort,
   }
   if (!is.null(ageRange)) {
     cli::cli_inform(c("Trim age"))
-    newCohort <- newCohort %>%
-      dplyr::mutate(!!!datesAgeRange(ageRange)) %>%
+
+    for (j in seq_along(ageRange)) {
+      ageRange[[j]][is.infinite(ageRange[[j]])] <- 999L
+    }
+
+    newCohort <- newCohort |>
+      dplyr::mutate(!!!datesAgeRange(ageRange)) |>
       dplyr::mutate(
         !!!caseAge(ageRange),
         "cohort_start_date" = dplyr::if_else(
@@ -192,7 +194,7 @@ trimDemographics <- function(cohort,
   }
   if (!is.null(minPriorObservation)) {
     cli::cli_inform(c("Trim prior observation"))
-    newCohort <- newCohort %>%
+    newCohort <- newCohort |>
       dplyr::mutate("min_prior_observation" = as.integer(.data$min_prior_observation)) %>%
       dplyr::mutate(
         "new_cohort_start_date" = as.Date(
@@ -233,11 +235,7 @@ trimDemographics <- function(cohort,
     cli::cli_inform(c("Trim future observation"))
     newCohort <- newCohort %>%
       dplyr::filter(
-        !!CDMConnector::datediff(
-          start = "cohort_start_date",
-          end = "future_observation",
-          interval = "day"
-        ) >=
+        !!CDMConnector::datediff("cohort_start_date", "future_observation") >=
           .data$min_future_observation
       ) |>
       dplyr::compute(name = tmpNewCohort, temporary = FALSE)
@@ -306,15 +304,15 @@ trimDemographics <- function(cohort,
     dplyr::distinct() |>
     dplyr::rename("target_cohort_rand01" = "cohort_definition_id") |>
     dplyr::inner_join(newCohort |>
-      dplyr::select(dplyr::all_of(
-        c(
-          "cohort_definition_id",
-          "subject_id",
-          "cohort_start_date",
-          "cohort_end_date",
-          "target_cohort_rand01"
-        )
-      )), by = unique(c("target_cohort_rand01", "subject_id"))) |>
+                        dplyr::select(dplyr::all_of(
+                          c(
+                            "cohort_definition_id",
+                            "subject_id",
+                            "cohort_start_date",
+                            "cohort_end_date",
+                            "target_cohort_rand01"
+                          )
+                        )), by = unique(c("target_cohort_rand01", "subject_id"))) |>
     dplyr::select(!"target_cohort_rand01") |>
     dplyr::relocate(dplyr::all_of(omopgenerics::cohortColumns("cohort"))) |>
     dplyr::compute(name = name, temporary = FALSE) |>
@@ -327,6 +325,14 @@ trimDemographics <- function(cohort,
 
   omopgenerics::dropTable(cdm = cdm, name = dplyr::starts_with(tablePrefix))
 
+  useIndexes <- getOption("CohortConstructor.use_indexes")
+  if (!isFALSE(useIndexes)) {
+    addIndex(
+      cohort = newCohort,
+      cols = c("subject_id", "cohort_start_date")
+    )
+  }
+
   cli::cli_inform(c("v" = "Cohort trimmed"))
   return(newCohort)
 }
@@ -340,8 +346,8 @@ datesAgeRange <- function(ageRange) {
     unlist() |>
     unique()
   values <- values[!is.infinite(values)]
-  values <- values[values != 0]
-  glue::glue("as.Date(local(CDMConnector::dateadd('date_0', {values}, interval = 'year')))") |>
+  values <- values[values != 0] |> as.integer()
+  glue::glue("as.Date(clock::add_years(.data$date_0, {values}))") |>
     rlang::parse_exprs() |>
     rlang::set_names(glue::glue("date_{values}"))
 }
@@ -382,9 +388,9 @@ prepareColEnd <- function(x, col) {
     col,
     " == ",
     as.character(num),
-    " ~ as.Date(local(CDMConnector::dateadd(date = 'date_",
+    " ~ as.Date(clock::add_days(x = .data$date_",
     as.character(num + 1),
-    "', number = -1, interval = 'day')))"
+    ", n = -1L))"
   )
   if (infFlag) {
     x <- c(
